@@ -7,12 +7,12 @@
 ************************************************************************
 **
 **   Copyright (c):  2002      by Heiner Lamprecht
-**                   2007-2010 by Axel Pauli
+**                   2007-2011 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: flighttask.cpp 3981 2010-04-23 19:22:52Z axel $
+**   $Id: flighttask.cpp 4629 2011-05-14 19:22:48Z axel $
 **
 **   This class provides calculation, drawing and other support
 **   for flight tasks and contains the data of a task.
@@ -595,7 +595,7 @@ bool FlightTask::isFAI(double d_wp, double d1, double d2, double d3)
  * Draws course lines and turn point sectors/circles according to the
  * user configuration.
  */
-void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
+void FlightTask::drawTask( QPainter* painter, QList<Waypoint*> &drawnTp )
 {
   // qDebug ("FlightTask::drawTask");
 
@@ -645,6 +645,18 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
           drawnTp.append( tpList->at(loop) );
         }
 
+      // map projected point to map
+      QPoint mPoint(glMapMatrix->map(tpList->at(loop)->projP));
+
+      bool mPointIsContained = viewport.contains(mPoint);
+
+      if( mPointIsContained )
+        {
+          painter->setPen(QPen(Qt::black));
+          painter->setBrush( QBrush( Qt::black, Qt::SolidPattern ) );
+          painter->drawRect( mPoint.x()-5, mPoint.y()-5, 10, 10 );
+        }
+
       if( flightType == Unknown )
         {
           if( loop )
@@ -652,13 +664,10 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
               painter->setPen(QPen(courseLineColor, courseLineWidth));
               // Draws the course line
               painter->drawLine( glMapMatrix->map(tpList->at(loop - 1)->projP),
-               glMapMatrix->map(tpList->at(loop)->projP) );
+                                 glMapMatrix->map(tpList->at(loop)->projP) );
             }
         }
 
-      // map projected point to map
-      QPoint mPoint(glMapMatrix->map(tpList->at(loop)->projP));
-
       // convert biangle (90...180) from radian to degrees
       int biangle = (int) rint( ((tpList->at(loop)->angle) / M_PI ) * 180.0 );
 
@@ -666,7 +675,7 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
       {
       case TaskPointTypes::RouteP:
 
-        if( viewport.contains(mPoint) )
+        if( mPointIsContained )
           {
             QColor c;
 
@@ -689,14 +698,14 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
           {
             painter->setPen(QPen(courseLineColor, courseLineWidth));
             painter->drawLine( glMapMatrix->map(tpList->at(loop - 1)->projP),
-             glMapMatrix->map(tpList->at(loop)->projP) );
+                               glMapMatrix->map(tpList->at(loop)->projP) );
           }
 
         break;
 
       case TaskPointTypes::Begin:
 
-        if( viewport.contains(mPoint) )
+        if( mPointIsContained )
           {
             QColor c;
 
@@ -721,14 +730,14 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
           {
             painter->setPen(QPen(courseLineColor, courseLineWidth));
             painter->drawLine( glMapMatrix->map(tpList->at(loop - 1)->projP),
-             glMapMatrix->map(tpList->at(loop)->projP) );
+                               glMapMatrix->map(tpList->at(loop)->projP) );
           }
 
         break;
 
       case TaskPointTypes::End:
 
-        if( viewport.contains(mPoint) )
+        if( mPointIsContained )
           {
             QColor c;
 
@@ -761,7 +770,7 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
           {
             painter->setPen(QPen(courseLineColor, courseLineWidth));
             painter->drawLine( glMapMatrix->map(tpList->at(loop - 1)->projP),
-             glMapMatrix->map(tpList->at(loop)->projP ) );
+                               glMapMatrix->map(tpList->at(loop)->projP ) );
           }
 
         break;
@@ -774,7 +783,7 @@ void FlightTask::drawTask( QPainter* painter, QList<wayPoint*> &drawnTp )
  * FAI rules does not play a role for drawing.
  *
  */
-void FlightTask::circleSchemeDrawing( QPainter* painter, QList<wayPoint*> &drawnTp )
+void FlightTask::circleSchemeDrawing( QPainter* painter, QList<Waypoint*> &drawnTp )
 {
   extern MapConfig* _globalMapConfig;
 
@@ -819,6 +828,17 @@ void FlightTask::circleSchemeDrawing( QPainter* painter, QList<wayPoint*> &drawn
           drawnTp.append( tpList->at(loop) );
         }
 
+      QPoint mPoint (glMapMatrix->map(tpList->at(loop)->projP));
+
+      bool mPointIsContained = viewport.contains(mPoint);
+
+      if( mPointIsContained )
+        {
+          painter->setPen(QPen(Qt::black));
+          painter->setBrush( QBrush( Qt::black, Qt::SolidPattern ) );
+          painter->drawRect( mPoint.x()-5, mPoint.y()-5, 10, 10 );
+        }
+
       if( loop )
         {
           // Draws the course line
@@ -834,11 +854,9 @@ void FlightTask::circleSchemeDrawing( QPainter* painter, QList<wayPoint*> &drawn
           continue;
         }
 
-      QPoint mPoint (glMapMatrix->map(tpList->at(loop)->projP));
-
       // qDebug("MappedPoint: x=%d, y=%d", mPoint.x(), mPoint.y() );
 
-      if( ! viewport.contains(mPoint) )
+      if( ! mPointIsContained )
         {
           // ignore not visible points
           continue;
@@ -1233,7 +1251,7 @@ FlightTask::calculateFinalGlidePath( const int taskPointIndex,
 
   bool res = calculator->glidePath( bearing, Distance(distance * 1000.0),
                                     tpList->at( taskPointIndex )->elevation,
-                                    arrAlt, speed );
+                                    arrAlt, bestSpeed );
 
   if( ! res )
     {
