@@ -12,7 +12,7 @@
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: generalconfig.cpp 4597 2011-04-28 18:55:45Z axel $
+ **   $Id: generalconfig.cpp 4619 2011-05-04 19:32:17Z axel $
  **
  ***********************************************************************/
 
@@ -1562,6 +1562,11 @@ QString GeneralConfig::getDefaultProxy()
 {
   char* proxy = getenv("http_proxy");
 
+  if( proxy == 0 )
+    {
+      proxy = getenv("HTTP_PROXY");
+    }
+
   if( proxy )
     {
       QString qProxy(proxy);
