@@ -3,10 +3,10 @@
  -----------------------------------------
  begin                : Sun Jul 21 2002
  copyright            : (C) 2002      by André Somers
- ported to Qt4.x/X11  : (C) 2007-2010 by Axel Pauli
+ ported to Qt4.x/X11  : (C) 2007-2011 by Axel Pauli
  maintainer           : axel@kflog.org
 
- $Id: mainwindow.cpp 4396 2010-11-11 21:20:47Z axel $
+ $Id: mainwindow.cpp 4619 2011-05-04 19:32:17Z axel $
 
 ****************************************************************************/
 
@@ -33,6 +33,7 @@
 
 #include <QtGui>
 
+#include "aboutwidget.h"
 #include "generalconfig.h"
 #include "mainwindow.h"
 #include "mapconfig.h"
@@ -119,9 +120,6 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
   helpMenu = 0;
   logger = static_cast<IgcLogger *> (0);
 
-  // Eggert: make sure the app uses utf8 encoding for translated widgets
-  QTextCodec::setCodecForTr( QTextCodec::codecForName ("UTF-8") );
-
   // Get application font for user manipulations
   QFont appFt = QApplication::font();
 
@@ -198,8 +196,12 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
   // get last saved window geometric from GeneralConfig and set it again
   resize( GeneralConfig::instance()->getWindowSize() );
 
-  qDebug( "Cumulus, Release: %s, Build date:  %s based on Qt/X11 Version %s",
-           CU_VERSION, __DATE__, QT_VERSION_STR );
+  qDebug() << "Cumulus Release:"
+           << QCoreApplication::applicationVersion()
+           << "Build date:"
+           << GeneralConfig::instance()->getBuiltDate()
+           << "based on Qt/X11 Version"
+           << QT_VERSION_STR;
 
   qDebug( "Desktop size is %dx%d, width=%d, height=%d",
           QApplication::desktop()->screenGeometry().width(),
@@ -222,6 +224,7 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
   char *ldpath = getenv( "LD_LIBRARY_PATH" );
   char *display = getenv( "DISPLAY" );
   char *proxy = getenv( "http_proxy" );
+  char *Proxy = getenv( "HTTP_PROXY" );
 
   qDebug( "PWD=%s", pwd ? pwd : "NULL" );
   qDebug( "USER=%s", user ? user : "NULL" );
@@ -230,7 +233,8 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
   qDebug( "LD_LIBRARY_PATH=%s", ldpath ? ldpath : "NULL" );
   qDebug( "QDir::homePath()=%s", QDir::homePath().toLatin1().data() );
   qDebug( "DISPLAY=%s", display ? display : "NULL" );
-  qDebug( "HTTP_PROXY=%s", proxy ? proxy : "NULL" );
+  qDebug( "http_proxy=%s", proxy ? proxy : "NULL" );
+  qDebug( "HTTP_PROXY=%s", Proxy ? Proxy : "NULL" );
 
   qDebug( "UserDataDir=%s",
           GeneralConfig::instance()->getUserDataDirectory().toLatin1().data() );
@@ -243,7 +247,7 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
 
   this->installEventFilter( this );
 
-  setWindowIcon( QIcon(GeneralConfig::instance()->loadPixmap("cumulus.png")) );
+  setWindowIcon( QIcon(GeneralConfig::instance()->loadPixmap("cumulus-desktop26x26.png")) );
   setWindowTitle( "Cumulus" );
 
 #ifdef MAEMO
@@ -280,7 +284,10 @@ void MainWindow::slotCreateApplicationWidgets()
 
 #ifdef MAEMO
 
-  ossoContext = osso_initialize( "org.kflog.Cumulus", CU_VERSION, false, 0 );
+  ossoContext = osso_initialize( "org.kflog.Cumulus",
+                                 QCoreApplication::applicationVersion().toAscii().data(),
+                                 false,
+                                 0 );
 
   if( ! ossoContext )
     {
@@ -349,7 +356,7 @@ void MainWindow::slotCreateApplicationWidgets()
   viewWP = new WaypointListView( this );
 
   QVector<enum MapContents::MapContentsListID> itemList;
-  itemList << MapContents::AirfieldList << MapContents::GliderSiteList;
+  itemList << MapContents::AirfieldList << MapContents::GliderfieldList;
   viewAF = new AirfieldListView( itemList, this ); // airfields
 
   itemList.clear();
@@ -385,8 +392,8 @@ void MainWindow::slotCreateApplicationWidgets()
   GpsNmea::gps->blockSignals( true );
   logger = IgcLogger::instance();
 
-  initActions();
-  initMenuBar();
+  createActions();
+  createMenuBar();
 
   ws->slot_SetText1( tr( "Setting up connections..." ) );
 
@@ -439,83 +446,83 @@ void MainWindow::slotCreateApplicationWidgets()
            viewMap, SLOT( slot_FlarmCount(int) ) );
 #endif
 
-  connect( viewWP, SIGNAL( newWaypoint( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
-  connect( viewWP, SIGNAL( deleteWaypoint( wayPoint* ) ),
-           calculator, SLOT( slot_WaypointDelete( wayPoint* ) ) );
+  connect( viewWP, SIGNAL( newWaypoint( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
+  connect( viewWP, SIGNAL( deleteWaypoint( Waypoint* ) ),
+           calculator, SLOT( slot_WaypointDelete( Waypoint* ) ) );
   connect( viewWP, SIGNAL( done() ),
            this, SLOT( slotSwitchToMapView() ) );
-  connect( viewWP, SIGNAL( info( wayPoint* ) ),
-           this, SLOT( slotSwitchToInfoView( wayPoint* ) ) );
+  connect( viewWP, SIGNAL( info( Waypoint* ) ),
+           this, SLOT( slotSwitchToInfoView( Waypoint* ) ) );
   connect( viewWP, SIGNAL( newHomePosition( const QPoint& ) ),
            _globalMapMatrix, SLOT( slotSetNewHome( const QPoint& ) ) );
   connect( viewWP, SIGNAL( gotoHomePosition() ),
            calculator, SLOT( slot_changePositionHome() ) );
 
-  connect( viewAF, SIGNAL( newWaypoint( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
+  connect( viewAF, SIGNAL( newWaypoint( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
   connect( viewAF, SIGNAL( done() ),
            this, SLOT( slotSwitchToMapView() ) );
-  connect( viewAF, SIGNAL( info( wayPoint* ) ),
-           this, SLOT( slotSwitchToInfoView( wayPoint* ) ) );
+  connect( viewAF, SIGNAL( info( Waypoint* ) ),
+           this, SLOT( slotSwitchToInfoView( Waypoint* ) ) );
   connect( viewAF, SIGNAL( newHomePosition( const QPoint& ) ),
            _globalMapMatrix, SLOT( slotSetNewHome( const QPoint& ) ) );
   connect( viewAF, SIGNAL( gotoHomePosition() ),
            calculator, SLOT( slot_changePositionHome() ) );
 
-  connect( viewOL, SIGNAL( newWaypoint( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
+  connect( viewOL, SIGNAL( newWaypoint( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
   connect( viewOL, SIGNAL( done() ),
            this, SLOT( slotSwitchToMapView() ) );
-  connect( viewOL, SIGNAL( info( wayPoint* ) ),
-           this, SLOT( slotSwitchToInfoView( wayPoint* ) ) );
+  connect( viewOL, SIGNAL( info( Waypoint* ) ),
+           this, SLOT( slotSwitchToInfoView( Waypoint* ) ) );
   connect( viewOL, SIGNAL( newHomePosition( const QPoint& ) ),
            _globalMapMatrix, SLOT( slotSetNewHome( const QPoint& ) ) );
   connect( viewOL, SIGNAL( gotoHomePosition() ),
            calculator, SLOT( slot_changePositionHome() ) );
 
-  connect( viewRP, SIGNAL( newWaypoint( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
+  connect( viewRP, SIGNAL( newWaypoint( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
   connect( viewRP, SIGNAL( done() ),
            this, SLOT( slotSwitchToMapView() ) );
-  connect( viewRP, SIGNAL( info( wayPoint* ) ),
-           this, SLOT( slotSwitchToInfoView( wayPoint* ) ) );
+  connect( viewRP, SIGNAL( info( Waypoint* ) ),
+           this, SLOT( slotSwitchToInfoView( Waypoint* ) ) );
   connect( viewRP, SIGNAL( newHomePosition( const QPoint& ) ),
            _globalMapMatrix, SLOT( slotSetNewHome( const QPoint& ) ) );
   connect( viewRP, SIGNAL( gotoHomePosition() ),
            calculator, SLOT( slot_changePositionHome() ) );
 
-  connect( viewTP, SIGNAL( newWaypoint( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
+  connect( viewTP, SIGNAL( newWaypoint( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
   connect( viewTP, SIGNAL( done() ),
            this, SLOT( slotSwitchToMapView() ) );
-  connect( viewTP, SIGNAL( info( wayPoint* ) ),
-           this, SLOT( slotSwitchToInfoView( wayPoint* ) ) );
+  connect( viewTP, SIGNAL( info( Waypoint* ) ),
+           this, SLOT( slotSwitchToInfoView( Waypoint* ) ) );
 
   connect( viewMap->_theMap, SIGNAL( isRedrawing( bool ) ),
            this, SLOT( slotMapDrawEvent( bool ) ) );
-  connect( viewMap->_theMap, SIGNAL( waypointSelected( wayPoint* ) ),
-           this, SLOT( slotSwitchToInfoView( wayPoint* ) ) );
+  connect( viewMap->_theMap, SIGNAL( waypointSelected( Waypoint* ) ),
+           this, SLOT( slotSwitchToInfoView( Waypoint* ) ) );
   connect( viewMap->_theMap, SIGNAL( airspaceWarning( const QString&, const bool ) ),
            this, SLOT( slotAlarm( const QString&, const bool ) ) );
   connect( viewMap, SIGNAL( toggleLDCalculation( const bool ) ),
            calculator, SLOT( slot_toggleLDCalculation(const bool) ) );
   connect( viewMap, SIGNAL( toggleMenu() ), this, SLOT( slotToggleMenu() ) );
 
-  connect( viewInfo, SIGNAL( waypointAdded( wayPoint& ) ),
-           viewWP, SLOT( slot_wpAdded( wayPoint& ) ) );
-  connect( viewInfo, SIGNAL( waypointSelected( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
+  connect( viewInfo, SIGNAL( waypointAdded( Waypoint& ) ),
+           viewWP, SLOT( slot_wpAdded( Waypoint& ) ) );
+  connect( viewInfo, SIGNAL( waypointSelected( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
   connect( viewInfo, SIGNAL( newHomePosition( const QPoint& ) ),
            _globalMapMatrix, SLOT( slotSetNewHome( const QPoint& ) ) );
   connect( viewInfo, SIGNAL( gotoHomePosition() ),
            calculator, SLOT( slot_changePositionHome() ) );
 
   connect( listViewTabs, SIGNAL( currentChanged( int ) ),
-           this, SLOT( slot_tabChanged( int ) ) );
+           this, SLOT( slotTabChanged( int ) ) );
 
-  connect( calculator, SIGNAL( newWaypoint( const wayPoint* ) ),
-           viewMap, SLOT( slot_Waypoint( const wayPoint* ) ) );
+  connect( calculator, SIGNAL( newWaypoint( const Waypoint* ) ),
+           viewMap, SLOT( slot_Waypoint( const Waypoint* ) ) );
   connect( calculator, SIGNAL( newBearing( int ) ),
            viewMap, SLOT( slot_Bearing( int ) ) );
   connect( calculator, SIGNAL( newRelBearing( int ) ),
@@ -570,7 +577,7 @@ void MainWindow::slotCreateApplicationWidgets()
   connect( logger, SIGNAL( logging( bool ) ),
            viewMap, SLOT( slot_setLoggerStatus() ) );
   connect( logger, SIGNAL( logging( bool ) ),
-           this, SLOT( slot_Logging( bool ) ) );
+           this, SLOT( slotLogging( bool ) ) );
   connect( logger, SIGNAL( madeEntry() ),
            viewMap, SLOT( slot_LogEntry() ) );
 
@@ -761,7 +768,7 @@ void MainWindow::slotAlarm( const QString& msg, const bool sound )
   viewMap->slot_info( msg );
 }
 
-void MainWindow::initMenuBar()
+void MainWindow::createMenuBar()
 {
   fileMenu = menuBar()->addMenu(tr("File"));
   fileMenu->addAction( actionFileQuit );
@@ -786,6 +793,8 @@ void MainWindow::initMenuBar()
   labelMenu->addSeparator();
   labelMenu->addAction( actionToggleLogging );
   labelMenu->addAction( actionToggleManualInFlight );
+  labelMenu->addSeparator();
+  labelMenu->addAction( actionToggleWindowSize );
   labelMenu->addAction( actionToggleStatusbar );
 
   mapMenu = menuBar()->addMenu(tr("Map"));
@@ -841,7 +850,7 @@ void MainWindow::slotSetMenuBarFontSize()
 }
 
 /** initializes all QActions of the application */
-void MainWindow::initActions()
+void MainWindow::createActions()
 {
   ws->slot_SetText1( tr( "Setting up key shortcuts ..." ) );
 
@@ -946,6 +955,20 @@ void MainWindow::initActions()
   connect( actionMenuBarToggle, SIGNAL( triggered() ),
            this, SLOT( slotToggleMenu() ) );
 
+  // Toggle window size
+  actionToggleWindowSize = new QAction( tr( "Window size" ), this );
+
+  // Hardware Key F6 for maximize/normalize screen under Maemo 4.
+  // Maemo 5 has no keys. Therefore the space key is activated for that.
+  QList<QKeySequence> wskList;
+  wskList << Qt::Key_Space << Qt::Key_F6;
+  actionToggleWindowSize->setShortcuts( wskList );
+  actionToggleWindowSize->setCheckable( true );
+  actionToggleWindowSize->setChecked( false );
+  addAction( actionToggleWindowSize );
+  connect( actionToggleWindowSize, SIGNAL( triggered() ),
+           this, SLOT( slotToggleWindowSize() ) );
+
   actionFileQuit = new QAction( tr( "&Exit" ), this );
   actionFileQuit->setShortcut( QKeySequence("Shift+E") );
   addAction( actionFileQuit );
@@ -1144,6 +1167,7 @@ void  MainWindow::toggleActions( const bool toggle )
   actionToggleTpLabels->setEnabled( toggle );
   actionToggleWpLabels->setEnabled( toggle );
   actionToggleLabelsInfo->setEnabled( toggle );
+  actionToggleWindowSize->setEnabled( toggle );
   actionEnsureVisible->setEnabled( toggle );
   actionSelectTask->setEnabled( toggle );
   actionStartFlightTask->setEnabled( toggle );
@@ -1273,7 +1297,7 @@ void MainWindow::slotToggleAfLabels( bool toggle )
   // save configuration change
   GeneralConfig::instance()->setMapShowAirfieldLabels( toggle );
   GeneralConfig::instance()->save();
-  viewMap->_theMap->scheduleRedraw(Map::airports);
+  viewMap->_theMap->scheduleRedraw(Map::airfields);
 }
 
 void MainWindow::slotToggleOlLabels( bool toggle )
@@ -1281,7 +1305,7 @@ void MainWindow::slotToggleOlLabels( bool toggle )
   // save configuration change
   GeneralConfig::instance()->setMapShowOutLandingLabels( toggle );
   GeneralConfig::instance()->save();
-  viewMap->_theMap->scheduleRedraw(Map::outlandingSites);
+  viewMap->_theMap->scheduleRedraw(Map::outlandings);
 }
 
 void MainWindow::slotToggleTpLabels( bool toggle )
@@ -1305,7 +1329,13 @@ void MainWindow::slotToggleLabelsInfo( bool toggle )
   // save configuration change
   GeneralConfig::instance()->setMapShowLabelsExtraInfo( toggle );
   GeneralConfig::instance()->save();
-  viewMap->_theMap->scheduleRedraw(Map::airports);
+  viewMap->_theMap->scheduleRedraw(Map::airfields);
+}
+
+
+void MainWindow::slotToggleWindowSize()
+{
+  setWindowState( windowState() ^ Qt::WindowFullScreen );
 }
 
 void MainWindow::slotViewStatusBar( bool toggle )
@@ -1317,7 +1347,7 @@ void MainWindow::slotViewStatusBar( bool toggle )
 }
 
 /** Called if the logging is actually toggled */
-void MainWindow::slot_Logging ( bool logging )
+void MainWindow::slotLogging ( bool logging )
 {
   actionToggleLogging->blockSignals( true );
   actionToggleLogging->setChecked( logging );
@@ -1331,9 +1361,9 @@ MainWindow::appView MainWindow::getView()
 }
 
 /** Called if the user clicks on a tabulator of the list view */
-void MainWindow::slot_tabChanged( int index )
+void MainWindow::slotTabChanged( int index )
 {
-  // qDebug("MainWindow::slot_tabChanged(): NewIndex=%d", index );
+  // qDebug("MainWindow::slotTabChanged(): NewIndex=%d", index );
 
   //switch to the correct view
   if ( index == listViewTabs->indexOf(viewWP) )
@@ -1364,7 +1394,7 @@ void MainWindow::slot_tabChanged( int index )
 
 
 /** Write property of internal view. */
-void MainWindow::setView( const appView& newVal, const wayPoint* wp )
+void MainWindow::setView( const appView& newVal, const Waypoint* wp )
 {
   // qDebug("MainWindow::setView called with argument %d", newVal);
 
@@ -1649,14 +1679,12 @@ void MainWindow::slotSwitchToReachListView()
   setView( rpView );
 }
 
-
 /** Switches to the WaypointList View */
 void MainWindow::slotSwitchToTaskListView()
 {
   setView( tpView );
 }
 
-
 /** This slot is called to switch to the info view. */
 void MainWindow::slotSwitchToInfoView()
 {
@@ -1687,9 +1715,8 @@ void MainWindow::slotSwitchToInfoView()
     }
 }
 
-
 /** @ee This slot is called to switch to the info view with selected waypoint. */
-void MainWindow::slotSwitchToInfoView( wayPoint* wp )
+void MainWindow::slotSwitchToInfoView( Waypoint* wp )
 {
   if( wp )
     {
@@ -1697,7 +1724,6 @@ void MainWindow::slotSwitchToInfoView( wayPoint* wp )
     }
 }
 
-
 /** Opens the configuration widget */
 void MainWindow::slotConfig()
 {
@@ -1720,47 +1746,87 @@ void MainWindow::slotConfig()
   cDlg->setVisible( true );
 }
 
-
 /** Closes the configuration or pre-flight widget */
 void MainWindow::slotCloseConfig()
 {
   setView( mapView );
-//  qDebug("* closing configView:  %s", calculator->gliderType().toLatin1().data() );
+
   if ( !calculator->gliderType().isEmpty() )
-    setWindowTitle ( "Cumulus - " + calculator->gliderType() );
+    {
+      setWindowTitle ( "Cumulus - " + calculator->gliderType() );
+    }
   else
-    setWindowTitle( "Cumulus" );
+    {
+      setWindowTitle( "Cumulus" );
+    }
 }
 
-/** Shows version and copyright information */
+/** Shows version, copyright, license and team information */
 void MainWindow::slotVersion()
 {
-  QMessageBox msgBox( QMessageBox::NoIcon,
-                      QObject::tr("About Cumulus"),
-                      QString(tr("Cumulus version %1")).arg( CU_VERSION),
-                      QMessageBox::Ok,
-                      this );
+  AboutWidget *aw = new AboutWidget( this );
 
-  QString infoText(tr(
-            "<html>"
-            "Cumulus %1<br>"
-            "<font size=-1>(compiled at %2 with QT %3)</font><br>"
-            "&copy; 2002-2010 by<br>"
-            "Andr&eacute; Somers, Eggert Ehmke<br>"
-            "Axel Pauli, Eckhard V&ouml;llm<br>"
-            "Josua Dietze, Michael Enke<br>"
-            "Hendrik M&uuml;ller, Florian Ehinger<br>"
-            "Heiner Lamprecht<br>"
-            "<a href=\"http://www.kflog.org/cumulus\">http://www.kflog.org/cumulus</a><br>"
-            "Published under the GPL<br>"
-            "</html>" ).arg( QString(CU_VERSION) ).arg( QString( __DATE__ )).arg( QString(QT_VERSION_STR) ) );
+  aw->setWindowIcon( QIcon(GeneralConfig::instance()->loadPixmap("cumulus-desktop26x26.png")) );
+  aw->setWindowTitle( tr( "About Cumulus") );
+  aw->setHeaderIcon( GeneralConfig::instance()->loadPixmap("cumulus-desktop48x48.png") );
 
+  QString header( tr("<html>Cumulus %1, &copy; 2002-2011, The Cumulus-Team</html>").arg( QCoreApplication::applicationVersion() ) );
 
-  msgBox.setInformativeText( infoText );
-  msgBox.exec();
+  aw->setHeaderText( header );
+
+  QString about( tr(
+          "<hml>"
+          "Cumulus %1, compiled at %2 with QT %3<br><br>"
+          "Homepage: <a href=\"http://www.kflog.org/cumulus/\">www.kflog.org/cumulus/</a><br><br>"
+          "Software Repository: <a href=\"https://svn.kflog.org/svn/repos/cumulus/qt4\">https://svn.kflog.org/svn/repos/cumulus/qt4</a><br><br>"
+          "Report bugs to: <a href=\"mailto:kflog.cumulus&#64;googlemail.com\">kflog.cumulus&#64;googlemail.com</a><br><br>"
+          "Published under the <a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">GPL</a>"
+          "</html>" ).arg( QCoreApplication::applicationVersion() )
+                     .arg( GeneralConfig::instance()->getBuiltDate() )
+                     .arg( QT_VERSION_STR ) );
+
+  aw->setAboutText( about );
+
+  QString team( tr(
+          "<hml>"
+          "<b>Project Leader</b>"
+          "<blockquote>"
+          "Axel Pauli &lt;<a href=\"mailto:axel&#64;kflog.org\">axel&#64;kflog.org</a>&gt;"
+          "</blockquote>"
+          "<b>Developers</b>"
+          "<blockquote>"
+          "Axel Pauli (Developer, Maintainer)<br>"
+          "Andr&eacute; Somers (Core-developer)<br>"
+          "Eggert Ehmke (Core-developer)<br>"
+          "Eckhard V&ouml;llm (Developer, NMEA Simulator)<br>"
+          "Josua Dietze (Developer)<br>"
+          "Michael Enke (Developer)<br>"
+          "Hendrik Hoeth (Developer)<br>"
+          "Florian Ehinger (KFLog-developer)<br>"
+          "Harald Maier (KFLog-developer)<br>"
+          "Heiner Lamprecht (KFLog-developer)<br>"
+          "Thomas Nielsen (KFLog-developer)"
+          "</blockquote>"
+          "<b>Contributors</b>"
+          "<blockquote>"
+          "Robin King (Help pages)<br>"
+          "Peter Turczak (Code Optimizations)<br>"
+          "Hendrik M&uuml;ller<br>"
+          "Stephan Danner<br>"
+          "Derrick Steed"
+          "</blockquote>"
+          "<b>Server Sponsor</b>"
+          "<blockquote>"
+          "Heiner Lamprecht &lt;<a href=\"mailto:heiner&#64;kflog.org\">heiner&#64;kflog.org</a>&gt;"
+          "</blockquote>"
+          "Thanks to all, who have made available this software!"
+          "<br></html>" ));
+
+  aw->setTeamText( team );
+  aw->resize( size() );
+  aw->setVisible( true );
 }
 
-
 /** opens help documentation in browser. */
 void MainWindow::slotHelp()
 {
@@ -1775,7 +1841,7 @@ void MainWindow::slotRememberWaypoint()
   static uint count = 1;
   QString name;
 
-  name = tr( "WP%1-%2" ).arg( count ).arg( QTime::currentTime().toString().left( 5 ) );
+  name = QString( tr("W%1-%2") ).arg( count ).arg( QTime::currentTime().toString("HH:mm") );
 
   // @AP: let us check, if the user waypoint is already known from its
   // position. In this case we will reject the insertion to avoid senseless
@@ -1783,11 +1849,11 @@ void MainWindow::slotRememberWaypoint()
 
   QPoint pos = calculator->getlastPosition();
 
-  QList<wayPoint>& wpList = _globalMapContents->getWaypointList();
+  QList<Waypoint>& wpList = _globalMapContents->getWaypointList();
 
   for ( int i = 0; i < wpList.count(); i++ )
     {
-      const wayPoint &wpItem = wpList.at(i);
+      const Waypoint &wpItem = wpList.at(i);
 
       if ( wpItem.origP == pos )
         {
@@ -1797,7 +1863,7 @@ void MainWindow::slotRememberWaypoint()
 
   count++;
 
-  wayPoint wp;
+  Waypoint wp;
 
   wp.name = name;
   wp.origP = calculator->getlastPosition();
@@ -1805,7 +1871,7 @@ void MainWindow::slotRememberWaypoint()
   wp.description = tr( "user created" );
   wp.comment = tr("created by remember action at ") +
   QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss");
-  wp.importance = wayPoint::High; // high to make sure it is visible
+  wp.priority = Waypoint::High; // high to make sure it is visible
   wp.frequency = 0.0;
   wp.runway = 0;
   wp.length = 0;
@@ -1813,6 +1879,7 @@ void MainWindow::slotRememberWaypoint()
   wp.elevation = int ( ( alt.gpsAltitude - alt.gndAltitude ).getMeters() );
   wp.type = BaseMapElement::Turnpoint;
   wp.isLandable = false;
+  wp.country = GeneralConfig::instance()->getHomeCountryCode();
 
   viewWP->slot_wpAdded( wp );
 
@@ -1916,7 +1983,7 @@ void MainWindow::slotReadconfig()
           listViewTabs->removeTab( listViewTabs->indexOf(viewOL) );
           listViewTabs->blockSignals( false );
           viewRP->clearList();  // this clears the outlanding list in the view
-          viewMap->_theMap->scheduleRedraw(Map::outlandingSites);
+          viewMap->_theMap->scheduleRedraw(Map::outlandings);
           _outlandingListVisible = false;
         }
     }
@@ -1924,7 +1991,6 @@ void MainWindow::slotReadconfig()
   viewMap->_theMap->scheduleRedraw();
 }
 
-
 /** Called if the status of the GPS changes, and controls the availability of manual navigation. */
 void MainWindow::slotGpsStatus( GpsNmea::GpsStatus status )
 {
@@ -2019,8 +2085,8 @@ void MainWindow::slotPreFlight(const char *tabName)
   connect( cDlg, SIGNAL( newTaskSelected() ),
            IgcLogger::instance(), SLOT( slotNewTaskSelected() ) );
 
-  connect( cDlg, SIGNAL( newWaypoint( wayPoint*, bool ) ),
-           calculator, SLOT( slot_WaypointChange( wayPoint*, bool ) ) );
+  connect( cDlg, SIGNAL( newWaypoint( Waypoint*, bool ) ),
+           calculator, SLOT( slot_WaypointChange( Waypoint*, bool ) ) );
 
   connect( cDlg, SIGNAL( closeConfig() ),
            this, SLOT( slotCloseConfig() ) );
@@ -2074,14 +2140,6 @@ bool MainWindow::eventFilter( QObject *o , QEvent *e )
       QKeyEvent *k = ( QKeyEvent* ) e;
 
       qDebug( "Keycode of pressed key: %d, %X", k->key(), k->key() );
-
-      if( k->key() == Qt::Key_F6 || k->key() == Qt::Key_Space )
-        {
-          // Hardware Key F6 for maximize/normalize screen under Maemo 4.
-          // Maemo 5 has no keys. Therefore the space key is activated for that.
-          setWindowState(windowState() ^ Qt::WindowFullScreen);
-          return true;
-        }
     }
 
   return QWidget::eventFilter( o, e ); // standard event processing;
@@ -2090,7 +2148,7 @@ bool MainWindow::eventFilter( QObject *o , QEvent *e )
 /** Called to select the home site position */
 void MainWindow::slotNavigate2Home()
 {
-  wayPoint wp;
+  Waypoint wp;
 
   wp.name = tr("Home");
   wp.description = tr("Home Site");
